(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms'), require('rxjs'), require('rxjs/operators'), require('@angular/common'), require('@angular/material/icon'), require('@angular/material/button'), require('@angular/material/input'), require('@angular/material/menu'), require('@angular/material/autocomplete'), require('@angular/flex-layout'), require('ngx-ellipsis'), require('@npcz/ngx-highlight')) :
    typeof define === 'function' && define.amd ? define('@npcz/ngx-search-bar', ['exports', '@angular/core', '@angular/forms', 'rxjs', 'rxjs/operators', '@angular/common', '@angular/material/icon', '@angular/material/button', '@angular/material/input', '@angular/material/menu', '@angular/material/autocomplete', '@angular/flex-layout', 'ngx-ellipsis', '@npcz/ngx-highlight'], factory) :
    (global = global || self, factory((global.npcz = global.npcz || {}, global.npcz['ngx-search-bar'] = {}), global.ng.core, global.ng.forms, global.rxjs, global.rxjs.operators, global.ng.common, global.ng.material.icon, global.ng.material.button, global.ng.material.input, global.ng.material.menu, global.ng.material.autocomplete, global.ng.flexLayout, global.ngxEllipsis, global.npczNgxHighlight));
}(this, (function (exports, core, forms, rxjs, operators, common, icon, button, input, menu, autocomplete, flexLayout, ngxEllipsis, ngxHighlight) { 'use strict';

    // Copyright (c) 2019-2020 The Authors
    var SearchBarComponent = /** @class */ (function () {
        function SearchBarComponent(_fb) {
            this._fb = _fb;
            this.highlightStyle = {
                hover: 'background',
                focus: 'outline',
            };
            this.search = new core.EventEmitter();
            this.changes = new core.EventEmitter();
            this.searchQuery = '';
            // Public because of use in the template, but not intended to be used outside
            // of this component
            this._searchForm = this._fb.group({
                searchInput: null,
            });
            // Automatic unsubscription when the component is destroyed
            // We don't want an emitted value, just the fact of emitting is enough
            this._ngUnsubscribe$ = new rxjs.Subject();
        }
        Object.defineProperty(SearchBarComponent.prototype, "categoryList", {
            get: function () {
                return this._categoryList;
            },
            set: function (value) {
                if (value && value.length > 0)
                    this._categoryList = value;
                else
                    this._categoryList = null;
                if (!this.category && this._categoryList) {
                    this.category = this._categoryList[0];
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(SearchBarComponent.prototype, "autoComplete", {
            get: function () {
                return this._autoComplete;
            },
            set: function (value) {
                this._autoComplete = value;
                this._setupAutoCompleteSelectionHandler();
            },
            enumerable: false,
            configurable: true
        });
        SearchBarComponent.prototype.ngOnInit = function () {
            var _this = this;
            if (this.disabled)
                this._searchForm.get('searchInput').disable();
            this._searchForm
                .get('searchInput')
                .valueChanges.pipe(operators.takeUntil(this._ngUnsubscribe$))
                .subscribe(function (value) {
                if (_this.searchQuery != value) {
                    _this.searchQuery = value;
                    //console.debug(`emit changes: ${this.category} / ${this.searchQuery}`);
                    _this.changes.emit({
                        category: _this.category,
                        query: _this.searchQuery,
                    });
                }
            });
        };
        SearchBarComponent.prototype.ngOnDestroy = function () {
            this._ngUnsubscribe$.next();
            this._ngUnsubscribe$.complete();
        };
        SearchBarComponent.prototype.clear = function () {
            this._searchForm.get('searchInput').setValue('');
            this._setFocusToSearchInput();
        };
        SearchBarComponent.prototype.enable = function () {
            this._searchForm.enable();
            this.disabled = false;
        };
        SearchBarComponent.prototype.disable = function () {
            this._searchForm.disable();
            this.disabled = true;
        };
        SearchBarComponent.prototype.focus = function () {
            this._setFocusToSearchInput();
        };
        SearchBarComponent.prototype._onCategorySelected = function (value) {
            if (this.category != value) {
                this.category = value;
                // console.debug(`emit changes: ${this.category} / ${this.searchQuery}`);
                this.changes.emit({
                    category: this.category,
                    query: this.searchQuery,
                });
            }
        };
        SearchBarComponent.prototype._onCategoryMenuClosed = function () {
            this._setFocusToSearchInput();
        };
        SearchBarComponent.prototype._onSubmit = function () {
            // console.debug(`submit: ${this.category} / ${this.searchQuery}`);
            this.search.emit({
                category: this.category,
                query: this.searchQuery,
            });
            this._searchInput.nativeElement.blur();
        };
        SearchBarComponent.prototype._setupAutoCompleteSelectionHandler = function () {
            var _this = this;
            this._autoComplete.optionSelected
                .pipe(operators.takeUntil(this._ngUnsubscribe$))
                .subscribe(function () {
                // Trigger a form submit by clicking the submit button
                _this._submitButton._elementRef.nativeElement.click();
            });
        };
        SearchBarComponent.prototype._setFocusToSearchInput = function () {
            this._searchInput.nativeElement.focus();
            // Move the cursor to the end of the text input value so that the user is
            // ready to type
            this._moveCursorToEnd();
        };
        SearchBarComponent.prototype._moveCursorToEnd = function () {
            var el = this._searchInput.nativeElement;
            el.selectionStart = el.selectionEnd = el.value.length;
        };
        return SearchBarComponent;
    }());
    SearchBarComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'hc-search-bar',
                    template: "<!--\n  ~ Copyright (c) 2019-2020 The Authors\n  ~ This file is part of @npcz/ngx-search-bar\n  ~ https://github.com/abdes/happy-coding\n  ~\n  ~ SPDX-License-Identifier: BSD-3-Clause\n  -->\n\n<form\n  [formGroup]=\"_searchForm\"\n  class=\"search__wrapper\"\n  [hcHighlight]=\"highlightStyle\"\n  (ngSubmit)=\"_onSubmit()\"\n>\n  <div class=\"search__container\" fxLayout=\"row\">\n    <!--\n      Set the type to 'button' so that the only submit button in the form is\n      the 'search__submit' button\n    -->\n    <button\n      type=\"button\"\n      *ngIf=\"categoryList\"\n      mat-stroked-button\n      class=\"search-category__button\"\n      [disabled]=\"disabled\"\n      [matMenuTriggerFor]=\"categoryMenu\"\n      (menuClosed)=\"_onCategoryMenuClosed()\"\n    >\n      <div fxLayout=\"row\" fxFlex=\"grow\">\n        <div\n          class=\"search-category__text\"\n          fxFlex=\"grow\"\n          ellipsis\n          [ellipsis-content]=\"category\"\n        ></div>\n        <mat-icon fxFlexAlign=\"center\">arrow_drop_down</mat-icon>\n      </div>\n    </button>\n\n    <!--\n      Because autocomplete is optional, we avoid errors on the input field by\n      setting the matAutocompleteDisabled property based on whether we do have\n      an autoComplete component set or not.\n    -->\n    <input\n      #search__input\n      type=\"text\"\n      matInput\n      class=\"search__input\"\n      fxFlex=\"grow\"\n      [placeholder]=\"placeholder\"\n      formControlName=\"searchInput\"\n      [matAutocomplete]=\"autoComplete\"\n      [matAutocompleteDisabled]=\"!autoComplete\"\n    />\n    <div *ngIf=\"searchQuery && clearButton\" fxLayout=\"row\">\n      <!--\n        Set the type to 'button' so that the only submit button in the form is\n        the 'search__submit' button\n      -->\n      <button\n        #search__clear\n        class=\"search__clear\"\n        [disabled]=\"disabled\"\n        type=\"button\"\n        mat-icon-button\n        aria-label=\"Clear\"\n        (click)=\"clear()\"\n      >\n        <mat-icon>close</mat-icon>\n      </button>\n      <div fxFlexAlign=\"center\" class=\"clear__separator\"></div>\n    </div>\n    <!-- This is the only button that must be set with type 'submit' -->\n    <button\n      #search__submit\n      class=\"search__submit\"\n      type=\"submit\"\n      mat-icon-button\n      [disabled]=\"disabled\"\n    >\n      <mat-icon>search</mat-icon>\n    </button>\n  </div>\n</form>\n\n<mat-menu #categoryMenu=\"matMenu\">\n  <ng-template matMenuContent>\n    <button\n      *ngFor=\"let category of categoryList\"\n      (click)=\"_onCategorySelected(category)\"\n      mat-menu-item\n    >\n      {{ category }}\n    </button>\n  </ng-template>\n</mat-menu>\n",
                    styles: [".clear__separator{border-right:thin;border-right-style:solid;height:60%;margin-right:5px;width:5px}.search__input{border:none;margin:0;outline:none}.search__wrapper{border-radius:8px;margin:4px;padding:5px}.search-category__button{flex:1 0 20%;margin-right:5px;max-width:160px;min-width:80px;padding:0 0 0 5px}.search-category__text{overflow:hidden}"]
                },] }
    ];
    SearchBarComponent.ctorParameters = function () { return [
        { type: forms.FormBuilder }
    ]; };
    SearchBarComponent.propDecorators = {
        _searchInput: [{ type: core.ViewChild, args: ['search__input',] }],
        _submitButton: [{ type: core.ViewChild, args: ['search__submit',] }],
        placeholder: [{ type: core.Input }],
        clearButton: [{ type: core.Input }],
        categoryList: [{ type: core.Input }],
        category: [{ type: core.Input }],
        disabled: [{ type: core.Input }],
        highlightStyle: [{ type: core.Input }],
        autoComplete: [{ type: core.Input }],
        search: [{ type: core.Output }],
        changes: [{ type: core.Output }]
    };

    // Copyright (c) 2019-2020 The Authors
    var SearchBarModule = /** @class */ (function () {
        function SearchBarModule() {
        }
        return SearchBarModule;
    }());
    SearchBarModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        // Angular
                        common.CommonModule,
                        forms.FormsModule,
                        forms.ReactiveFormsModule,
                        // Material
                        icon.MatIconModule,
                        button.MatButtonModule,
                        input.MatInputModule,
                        menu.MatMenuModule,
                        autocomplete.MatAutocompleteModule,
                        // Other external dependencies
                        flexLayout.FlexLayoutModule,
                        ngxEllipsis.EllipsisModule,
                        ngxHighlight.HighlightModule,
                    ],
                    declarations: [SearchBarComponent],
                    exports: [SearchBarComponent],
                },] }
    ];

    // Copyright (c) 2019-2020 The Authors

    // Copyright (c) 2019-2020 The Authors

    /**
     * Generated bundle index. Do not edit.
     */

    exports.SearchBarComponent = SearchBarComponent;
    exports.SearchBarModule = SearchBarModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=npcz-ngx-search-bar.umd.js.map
